backButtonLabel property
The label for the back button, used in CupertinoNavigationBar and CupertinoSliverNavigationBar.
Implementation
@override
String get backButtonLabel => "";
The label for the back button, used in CupertinoNavigationBar and CupertinoSliverNavigationBar.
@override
String get backButtonLabel => "";