timerPickerMinuteLabel method
Label that appears next to the minute picker in
CupertinoTimerPicker when selected minute value is minute.
This function will deal with pluralization based on the minute parameter.
Implementation
@override
String timerPickerMinuteLabel(int minute) => '分';